//package iku.os.apkManager;
//
//import static iku.os.apkManager.apk.clientInstall;
//
//import android.content.Context;
//import android.content.pm.ApplicationInfo;
//import android.content.pm.PackageInfo;
//import android.content.pm.PackageManager;
//import android.util.Log;
//
//import java.io.File;
//import java.io.IOException;
//import java.util.ArrayList;
//import java.util.List;
//
//import iku.os.FileUtils.FileUtils;
//import iku.os.ikuterminal.MainActivity;
//
//public class xapk {
//
//    private static final String TAG = "apkManager xapk";
//    private String name;
//    private String apk_path;
//    private String zip_name;
//    private String baoming;
//    private String appName;
//
//    private void installxapk() {
//        new Thread(new Runnable() {
//            @Override
//            public void run() {
//
//                try {
//                    getName(apk_path,".xapk");
//                    Thread.sleep(3000);
//                    changeZip();
//                    Thread.sleep(120000);
//                    getZipApk();
//                    Thread.sleep(120000);
//                    obb_name();
//                    Thread.sleep(120000);
//                    installApk();
//                } catch (IOException | InterruptedException e) {
//                    e.printStackTrace();
//                }
//
//            }
//        }).start();
//
//    }
//
//
//    private static void changeZip() {
//        String[] split = appName.split(".xapk");
//        //分割后选择保留那段
//        zip_name = split[0];
//        Log.e("压缩包名", zip_name);
//
//
//        oldpath = apk_path + "/" + name;
//        Log.i("oldpath", oldpath);
//        newpath = apk_path + "/" + zip_name + ".zip";
//        Log.i("newpath", newpath);
//
//        //将xapk换成zip格式
//        FileUtils.renameFile(oldpath, newpath);
//
//        //进行解压
//        new Thread(new Runnable() {
//            @Override
//            public void run() {
//
//                try {
//                    sleep(3000);
//
//                    try {
//                        FileUtils.upZipFile(new File(newpath), apk_path + "/" + zip_name);
//                    } catch (IOException e) {
//                        e.printStackTrace();
//                    }
//
//                } catch (InterruptedException e) {
//                    e.printStackTrace();
//                }
//
//
//                Log.e("zip：", "文件解压成功");
//            }
//        }).start();
//
//    FileUtils.renameFile(newpath, oldpath);
//
//    }
//
//
//    private void getName(String path,String houzhui) throws IOException {
//
//        //新建ArrayList
//        List<String> list = new ArrayList<>();
//        //获取指定路径下的所有文件
//        list = FileUtils.getFilesAllName(path);
//        if(list != null){
//            for(String listname : list ){
//                Log.e("TAG","listname :"+listname );
//                //判断文件是不是想要查找后缀
//                if(listname .endsWith(houzhui)){
//                    //获取路径下最后一个‘/’后的坐标
//                    int lastindex = listname .lastIndexOf("/");
//                    //获取具体文件名称
//                    name= listname .substring(lastindex+1,listname.length());
//                    //获取到想要的名称后，去干你想干的事
//                    //dosomething
//                    Log.e("name",name);
//
//                }
//            }
//        }
//
//    }
//
//    private void getZipApk() throws IOException {
//
//
//        new Thread(new Runnable() {
//            @Override
//            public void run() {
//
//                try {
//                    Thread.sleep(65000);
//                    String apkpath = apk_path+"/"+zip_name;
//
//                    Log.e("sss",apkpath);
//                    //获取apk
//                    getName(apkpath,".apk");
//
//                    baoming = getApkPackageName(MainActivity.this,apkpath+"/"+name);
//
//                    Log.e("baoming",baoming+"获取成功");
//                } catch (InterruptedException | IOException e) {
//                    e.printStackTrace();
//                }
//
//            }
//        }).start();
//    }
//
//
//    public static String getApkPackageName(Context context, String apkPath) {
//
//        PackageManager pm = context.getPackageManager();
//        PackageInfo info = pm.getPackageArchiveInfo(apkPath, PackageManager.GET_ACTIVITIES);
//        ApplicationInfo appInfo = null;
//        String packageName = "";
//        if (info != null) {
//            appInfo = info.applicationInfo;
//            packageName = appInfo.packageName;  //得到apk包名
//        }
//        return packageName;
//    }
//
//    private void obb_name() throws IOException {
//
//        //首先先获取obb文件所在的位置
//        String obb_path = apk_path+"/"+zip_name+"/Android/obb/"+baoming;
//        Log.e("Tag",obb_path);
//
//        getName(obb_path,".obb");
//
//        //创建文件夹
//        FileUtils.createDir("/sdcard/Android/obb/"+baoming);
//
//        new Thread(new Runnable() {
//            @Override
//            public void run() {
//
//                try {
//                    Thread.sleep(3000);//休眠3秒
//                    //复制到/sdcard/Android/obb/ 文件下
//                    try {
//
//                        String sourceFile = obb_path+"/"+name;
//                        Log.e("sourceFile",sourceFile);
//                        String targetFile = "/sdcard/Android/obb"+"/"+baoming+"/"+name;
//                        Log.e("targetFile",targetFile);
//                        FileUtils.copyFile(new File(sourceFile),new File(targetFile));
//                    } catch (IOException e) {
//                        e.printStackTrace();
//                    }
//
//                } catch (InterruptedException e) {
//                    e.printStackTrace();
//                }
//
//
//                Log.e("obb：","文件复制成功");
//
//            }
//        }).start();
//
//
//    }
//
//
//    //安装压缩包中的apk
//    private void installApk() throws IOException {
//
//        String apkpath = apk_path+"/"+zip_name;
//
//        Log.e("sss",apkpath);
//        //获取apk
//        getName(apkpath,".apk");
//
//        baoming = getApkPackageName(MainActivity.this,apkpath+"/"+name);
//
//        Log.e("baoming",baoming);
//
//
//
//        clientInstall(new File(apkpath+"/"+name));
//
//        Log.e("install","apk安装成功");
//
//        //65秒后删除压缩后的文件
//        new Thread(new Runnable() {
//            @Override
//            public void run() {
//
//
//                try {
//                    Thread.sleep(65000);
//
//                    FileUtils.deleteDirWihtFile(new File(apkpath));
//
//                } catch (InterruptedException e) {
//                    e.printStackTrace();
//                }
//
//                Log.e("delete","文件删除成功");
//
//            }
//        }).start();
//
//    }
//}
